Name:		ccache
Version:	3.1.8
Release:	%mkrel 2
Group:		Development/Tools
Summary:	Compiler Cache
License:	GPLv3+
URL:		http://ccache.samba.org/
Source0:	http://samba.org/ftp/ccache/%{name}-%{version}.tar.xz

%description
ccache is a compiler cache. It acts as a caching pre-processor to 
C/C++ compilers, using the -E compiler switch and a hash to detect 
when a compilation can be satisfied from cache. This often results 
in a 5 to 10 times speedup in common compilations.

To enable ccache's default use, the system admin should modify 
%{_sysconfdir}/sysconfig/ccache to "yes". If its default use is not 
enabled and you wish to use it, simply add %{_prefix}/%{_lib}/ccache/bin/ to 
the start of your \$PATH

%prep
%setup -q

%build
%configure2_5x
%make

cat <<EOF > %{name}.sh

if [ -f /etc/sysconfig/ccache ]; then
    . /etc/sysconfig/ccache
fi
if [ "\$USE_CCACHE_DEFAULT" = "yes" ]; then
    if [ -z \`echo "\$PATH" | grep "%_libdir/ccache/bin"\` ]; then
        export PATH="%_libdir/ccache/bin:\$PATH"
    fi
fi
EOF

cat << EOF > %{name}.csh

if ( -f /etc/sysconfig/ccache ) then
    eval \`sed -n 's/^\([^#]*\)=\([^#]*\)/set \1=\2;/p' < /etc/sysconfig/ccache\`
endif
if ( "\$USE_CCACHE_DEFAULT" == "yes" ) then
    if ( "\$path" !~ *%_libdir/ccache/bin* ) then
        setenv path = ( %_libdir/ccache/bin \$path )
    endif
endif
EOF

%install
rm -rf %{buildroot}
install -dm 755 %{buildroot}{%{_bindir},%{_libdir}/ccache/bin,%{_mandir}/man1}
install -pm 755 ccache %{buildroot}%{_bindir}
install -pm 644 ccache.1 %{buildroot}%{_mandir}/man1
install -dm 755 %{buildroot}%{_sysconfdir}/profile.d
install -pm 755 %{name}.sh %{name}.csh %{buildroot}%{_sysconfdir}/profile.d
rm -f %{name}-%{version}.compilers
pref=`gcc -dumpmachine`

create_compiler() {
cat <<EOF > %{buildroot}%{_prefix}/%{_lib}/ccache/bin/$1
#!/bin/sh
if [ ! -x %_bindir/$1 ]; then
	echo Error: compiler $1 does not exist. >&2
	exit 127
fi
PATH=%_bindir:\$PATH
if [ -f /etc/sysconfig/ccache ]; then
	. /etc/sysconfig/ccache
	if [ "\$USE_CCACHE_WITH_ICECREAM" = "yes" ]; then
	PATH=%{_libdir}/icecc/bin:\$PATH
	fi
fi

ccache ${1} "\$@"
EOF
echo "%attr(0755,root,root) %{_libdir}/ccache/bin/$1" >> %{name}-%{version}.compilers
}

for name in gcc g++ c++; do
 for comp in $name $pref-$name ${pref/manbo/mandriva}-$name; do
  # check for backports that have no manbo:
  [ -e "%{buildroot}%{_libdir}/ccache/bin/$comp" ] || create_compiler $comp
 done
done
create_compiler cc

mkdir -p %{buildroot}%{_sysconfdir}/sysconfig/
cat <<EOF > %{buildroot}/%{_sysconfdir}/sysconfig/%{name}
# Should we add the ccache compiler symlinks to PATH
# yes|no
# Please note that if added to \$PATH the user can still disable 
# it with CCACHE_DISABLE
# If not enabled by default, the user can add %{_libdir}/ccache/bin/
# to their \$PATH
USE_CCACHE_DEFAULT="no"

# Enable icecream integration
USE_CCACHE_WITH_ICECREAM="no"

EOF

%files -f %{name}-%{version}.compilers
%dir %{_libdir}/ccache
%dir %{_libdir}/ccache/bin
%{_bindir}/ccache
%{_mandir}/man1/ccache.1*
%{_sysconfdir}/profile.d/*
%config(noreplace) %{_sysconfdir}/sysconfig/*



%changelog

* Fri Jan 11 2013 umeabot <umeabot> 3.1.8-2.mga3
+ Revision: 347438
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 09 2012 kamil <kamil> 3.1.8-1.mga3
+ Revision: 329206
- new bugfix releae 3.1.8

* Wed Oct 03 2012 malo <malo> 3.1.7-2.mga3
+ Revision: 302718
- update RPM group

* Thu Jan 12 2012 doktor5000 <doktor5000> 3.1.7-1.mga2
+ Revision: 195428
- new version 3.1.7
- removed obsolete %%clean section and empty %%defattr
- don't use macros for system executables

* Mon Jun 27 2011 ahmad <ahmad> 3.1.5-1.mga2
+ Revision: 114208
- Update to 3.1.5

* Wed Apr 20 2011 anssi <anssi> 3.1.4-1.mga1
+ Revision: 88971
- clean empty lines from the end of .spec
- new version
- imported package ccache

